@@ -15,6 +15,7 @@ using namespace std;
 //' @return a \code{matrix} containing each pair of start and end points
 //' on its columns, and the distance between these points in order to 
 //' produce the Minimum Spanning Tree.
+//' @noRd
 //'
 // [[Rcpp::export]]
 Rcpp::NumericMatrix mlpack_mst(arma::mat& data)
@@ -28,12 +29,17 @@ Rcpp::NumericMatrix mlpack_mst(arma::mat& data)
 	
 	arma::mat mstResults;
 	dtb.ComputeMST(mstResults);
-	// different than R logic -- it saves the results in mstResults
+	// different from R logic -- it saves the results in mstResults
 	
 	// adding 1 to rows "from" & "to" - v3
 	mstResults.row(0) = mstResults.row(0) + 1; //start index = 0 in C++
 	mstResults.row(1) = mstResults.row(1) + 1;
 	
+	// transpose the matrix back to how it was, for returning to R
+	data = data.t();
+	// pull request nr 1, based on the modify-in-place behaviour of Rcpp:
+	// sol: https://stackoverflow.com/questions/24112893/within-c-functions-how-are-rcpp-objects-passed-to-other-functions-by-referen).
+	
 	// returning a matrix instead of a list - v2
 	return Rcpp::wrap(mstResults); 
 }
